==> timemory-3.1.0.dev12.tar.gz: timemory-3.1.0.dev12/source/timemory/components/definition.hpp <==
// MIT License
//
// Copyright (c) 2020, The Regents of the University of California,
// through Lawrence Berkeley National Laboratory (subject to receipt of any
// required approvals from the U.S. Dept. of Energy).  All rights reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#pragma once

#include "timemory/components/allinea/components.hpp"
#include "timemory/components/caliper/components.hpp"
#include "timemory/components/craypat/components.hpp"
#include "timemory/components/cuda/components.hpp"
#include "timemory/components/cupti/components.hpp"
#include "timemory/components/general.hpp"
#include "timemory/components/gotcha/components.hpp"
#include "timemory/components/gperftools/components.hpp"
#include "timemory/components/likwid/components.hpp"
#include "timemory/components/ompt/components.hpp"
#include "timemory/components/papi/components.hpp"
#include "timemory/components/roofline/components.hpp"
#include "timemory/components/rusage/components.hpp"
#include "timemory/components/tau_marker/components.hpp"
#include "timemory/components/timing/components.hpp"
#include "timemory/components/trip_count/components.hpp"
#include "timemory/components/user_bundle/components.hpp"
#include "timemory/components/vtune/components.hpp"

==> timemory-3.2.0.dev0.tar.gz: timemory-3.2.0.dev0/source/timemory/components/definition.hpp <==
// MIT License
//
// Copyright (c) 2020, The Regents of the University of California,
// through Lawrence Berkeley National Laboratory (subject to receipt of any
// required approvals from the U.S. Dept. of Energy).  All rights reserved.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#pragma once

#include "timemory/components/allinea/components.hpp"
#include "timemory/components/caliper/components.hpp"
#include "timemory/components/craypat/components.hpp"
#include "timemory/components/cuda/components.hpp"
#include "timemory/components/cupti/components.hpp"
#include "timemory/components/data_tracker/components.hpp"
#include "timemory/components/gotcha/components.hpp"
#include "timemory/components/gperftools/components.hpp"
#include "timemory/components/io/components.hpp"
#include "timemory/components/likwid/components.hpp"
#include "timemory/components/ompt/components.hpp"
#include "timemory/components/papi/components.hpp"
#include "timemory/components/roofline/components.hpp"
#include "timemory/components/rusage/components.hpp"
#include "timemory/components/tau_marker/components.hpp"
#include "timemory/components/timing/components.hpp"
#include "timemory/components/trip_count/components.hpp"
#include "timemory/components/types.hpp"
#include "timemory/components/user_bundle/components.hpp"
#include "timemory/components/vtune/components.hpp"
